/*
 * Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either 
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>. */

#include "ErrorMessagesModel.h"

#include <vector>

#include <KDebug>

struct ErrorMessagesModel::Private
{
  std::vector<GTLCore::CompilationMessage> errorMessages;
};

ErrorMessagesModel::ErrorMessagesModel( const std::list<GTLCore::CompilationMessage>& _errorMessages) : d(new Private)
{
  d->errorMessages.insert( d->errorMessages.begin(), _errorMessages.begin(), _errorMessages.end() );
}

ErrorMessagesModel::~ErrorMessagesModel()
{
}

QVariant ErrorMessagesModel::data( const QModelIndex & index, int role ) const
{
  if( index.isValid() )
  {
    switch( role )
    {
      case Qt::DisplayRole:
          return QVariant( QString("%1: %2").arg( d->errorMessages[index.row()].line()).arg( d->errorMessages[index.row()].message().c_str()) );
      case Qt::ForegroundRole:
        return Qt::red;
      case LineRole:
        return QVariant( d->errorMessages[index.row()].line());
    }
  }
  return QVariant();
}

int ErrorMessagesModel::rowCount ( const QModelIndex & parent ) const
{
  Q_UNUSED( parent );
  return d->errorMessages.size();
}
