/*
 * Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either 
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>. */

#ifndef _SHIVA_RENDER_WINDOW_H_
#define _SHIVA_RENDER_WINDOW_H_

#include <QMutex>

#include "RenderWindow.h"

#include <GTLCore/Region.h>

class ImageViewer;
class ShivaRenderThread;
class TransformWidget;

namespace QtShiva {
  class KernelParametersWidget;
}

namespace OpenShiva {
  class Kernel;
}

class ShivaRenderWindow : public RenderWindow
{
  Q_OBJECT
  public:
    ShivaRenderWindow();
    ~ShivaRenderWindow();
    void setRegion(const GTLCore::RegionI& region);
    void setKernel(OpenShiva::Kernel* kernel);
  private slots:
    void render();
    void renderFinished();
  private:
    void startRendering();
  private:
    QMutex m_mutex;
    GTLCore::RegionI m_region;
    QtShiva::KernelParametersWidget* m_parametersWidget;
    TransformWidget* m_transformWidget;
    OpenShiva::Kernel* m_kernel;
    ImageViewer* m_imageViewer;
    ShivaRenderThread* m_thread;
    bool m_restart;
};

#endif
