/*
 * Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either 
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>. */

#ifndef GTLDESIGNER_H
#define GTLDESIGNER_H


#include <kxmlguiwindow.h>

#include "ui_ImagesDocker.h"

class GTLDesignerView;
class QPrinter;
class KToggleAction;
class KUrl;
class QImage;
class QListView;
class QModelIndex;
class ShivaRenderWindow;

namespace KTextEditor
{
  class Document;
  class View;
}

namespace OpenShiva {
  class Kernel;
}

/**
 * This class serves as the main window for GTLDesigner.  It handles the
 * menus, toolbars, and status bars.
 *
 * @short Main window class
 * @author Cyrille Berger <cberger@cberger.net>
 * @version 0.1
 */
class GTLDesigner : public KXmlGuiWindow
{
    enum Type {
      UNKNOWN,
      SHIVA_KERNEL,
      SHIVA_LIBRARY,
      CTL
    };
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    GTLDesigner();

    /**
     * Default Destructor
     */
    virtual ~GTLDesigner();
    void openFile( const KUrl& file );

private slots:
    void fileNew();
    void fileOpen();
    void fileSave();
    void fileSaveAs();
    void optionsPreferences();
    void optionsEditorPreferences();
    void executeRun();
    void executeCTL();
    void executeShiva();
    void updateCaption();
    
    void addImage();
    void removeImage();
    
    void errorLineActivated(const QModelIndex& index);
private:
    void setupActions();
    void showImage(const QImage&);
    void setupDockers();
  private:
    void updateType();
    KTextEditor::View *m_view;
    KTextEditor::Document *m_document;
    
    Ui::ImagesDocker* ui_imagesDocker;

    KToggleAction *m_toolbarAction;
    KToggleAction *m_statusbarAction;
    QListView* m_listView;
    Type m_type;
    
    ShivaRenderWindow* m_shivaRenderWindow;
};

#endif // _GTLDESIGNER_H_
