/*
 * Copyright (c) 2010 Cyrille Berger <cberger@cberger.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either 
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public 
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "TransformWidget.h"

#include <cmath>

#include <GTLCore/Transform.h>
#include <SpinBoxSliderConnector_p.h>

#define CONNECT(_SB_, _SL_) \
  { \
    QtShiva::SpinBoxSliderConnector* connector = new QtShiva::SpinBoxSliderConnector(this, _SB_, _SL_); \
    connect(connector, SIGNAL(valueChanged(double)), SIGNAL(transformChanged())); \
  }
  

TransformWidget::TransformWidget(QWidget* parent) : QWidget(parent)
{
  m_form.setupUi(this);
  
  // Translation
  CONNECT(m_form.spinBoxX, m_form.sliderX);
  CONNECT(m_form.spinBoxY, m_form.sliderY);

  // Scale
  CONNECT(m_form.spinBoxScaleH, m_form.sliderScaleH);
  CONNECT(m_form.spinBoxScaleV, m_form.sliderScaleV);
  
  // Rotation
  CONNECT(m_form.spinBoxRotation, m_form.sliderRotation);
  CONNECT(m_form.spinBoxCenterX, m_form.sliderCenterX);
  CONNECT(m_form.spinBoxCenterY, m_form.sliderCenterY);

  // Shear
  CONNECT(m_form.spinBoxShearH, m_form.sliderShearH);
  CONNECT(m_form.spinBoxShearV, m_form.sliderShearV);
}

TransformWidget::~TransformWidget()
{
}

inline double nonnull(double v)
{
  if( fabs(v) < 1e-6)
  {
    v = 1e-6 * ( ( v < 0.0) ? -1 : 1 );
  }
  return v;
}

GTLCore::Transform TransformWidget::transform() const
{
  GTLCore::Transform transfo;
  transfo.translate( m_form.spinBoxX->value(), m_form.spinBoxY->value());
  transfo.scale( nonnull(m_form.spinBoxScaleH->value()), nonnull(m_form.spinBoxScaleV->value()));
  double rCenterX = m_form.spinBoxCenterX->value();
  double rCenterY = m_form.spinBoxCenterY->value();
  transfo.rotate( m_form.spinBoxRotation->value() * M_PI / 180.0);
  if(rCenterX != 0.0 or rCenterY != 0.0)
  {
    GTLCore::Transform transfo1;
    transfo1.translate(-rCenterX, -rCenterY);
    GTLCore::Transform transfo2;
    transfo2.translate(rCenterX, rCenterY);
    transfo = transfo * transfo1;
    transfo = transfo2 * transfo;
  }
  transfo.shear( m_form.spinBoxShearH->value(), m_form.spinBoxShearV->value());
  return transfo.invert();
}

#include "TransformWidget.moc"
